%# BEGIN BPS TAGGED BLOCK {{{
%# 
%# COPYRIGHT:
%#  
%# This software is Copyright (c) 1996-2007 Best Practical Solutions, LLC 
%#                                          <jesse@bestpractical.com>
%# 
%# (Except where explicitly superseded by other copyright notices)
%# 
%# 
%# LICENSE:
%# 
%# This work is made available to you under the terms of Version 2 of
%# the GNU General Public License. A copy of that license should have
%# been provided with this software, but in any event can be snarfed
%# from www.gnu.org.
%# 
%# This work is distributed in the hope that it will be useful, but
%# WITHOUT ANY WARRANTY; without even the implied warranty of
%# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%# General Public License for more details.
%# 
%# You should have received a copy of the GNU General Public License
%# along with this program; if not, write to the Free Software
%# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
%# 02110-1301 or visit their web page on the internet at
%# http://www.gnu.org/copyleft/gpl.html.
%# 
%# 
%# CONTRIBUTION SUBMISSION POLICY:
%# 
%# (The following paragraph is not intended to limit the rights granted
%# to you to modify and distribute this software under the terms of
%# the GNU General Public License and is only of importance to you if
%# you choose to contribute your changes and enhancements to the
%# community by submitting them to Best Practical Solutions, LLC.)
%# 
%# By intentionally submitting any modifications, corrections or
%# derivatives to this work, or any other work intended for use with
%# Request Tracker, to Best Practical Solutions, LLC, you confirm that
%# you are the copyright holder for those contributions and you grant
%# Best Practical Solutions,  LLC a nonexclusive, worldwide, irrevocable,
%# royalty-free, perpetual, license to use, copy, create derivative
%# works based on those contributions, and sublicense and distribute
%# those contributions and any derivatives thereof.
%# 
%# END BPS TAGGED BLOCK }}}

<%init>
   my $title = loc('Become User');
   unless ($session{'CurrentUser'}->HasRight( Object=> $RT::System, Right => 'SuperUser')) {
       Abort(loc('This feature is only available to system administrators'));
   }

   my $users;
   if ( defined($ARGS{'UserName'}) ) {

      if (defined %session) {
         tied(%session)->delete;
      }
      $m->comp( '/Elements/SetupSessionCookie', %ARGS );
      $session{'CurrentUser'} = RT::CurrentUser->new();
      $session{'CurrentUser'}->Load($ARGS{'UserName'});
      $m->redirect($RT::WebURL);
      $m->abort();
   } else {

      $users = RT::Users->new($RT::SystemUser);
      $users->_DoSearch();
   }
</%init>

<& /Admin/Elements/Header, Title => $title &>
<& /Admin/Elements/ToolTabs,
    current_tab => 'Admin/Tools/BecomeUser.html',
    current_subtab => 'Admin/Tools/BecomeUser.html', 
    Title => $title &>

<h2><&|/l&>Select User</&></h2>
<form name=BecomeUser action=BecomeUser.html>
<select name="UserName" single size=5>
%while ( my $User = $users->Next )  {
<option <% ($User->Id == $session{'CurrentUser'}->Id) ? "SELECTED" : ''%>
%if ($ValueAttribute eq 'id') {
    value="<%$User->id%>"
%} elsif ($ValueAttribute eq 'Name') {
    value="<%$User->Name%>"
%} 
><%$User->Name . " (" . $User->RealName . ")" %></option>
%}
</select>
<& /Elements/Submit, Label => loc("Become User")&>
</form>

<%args>
   $ValueAttribute => 'id'
</%args>
